@@ -35,9 +35,11 @@ class Config:
     RABBIT_PASSWORD = 'guest'
     """RabbitMQ password."""
 
+    RABBIT_HEARTBEAT = 60
     RABBIT_CONNECT_TIMEOUT = 5
     RABBIT_READ_TIMEOUT = 5
     RABBIT_WRITE_TIMEOUT = 5
+    TCP_USER_TIMEOUT = 60
 
     # Instance Options
     ##################
